@@ -181,6 +181,7 @@ applet_fill (PanelApplet *applet)
 
     g_signal_connect (component, "ui-event", G_CALLBACK (ui_component_event), cd);
     gtk_widget_show (GTK_WIDGET(applet));
+    setup_box(cd);
     return(TRUE);
 }
 
@@ -401,6 +402,9 @@ static void
 about_cb(GtkWidget *w, gpointer data)
 {
     static GtkWidget   *about     = NULL;
+    GdkPixbuf	       *pixbuf;
+    GError	       *error     = NULL;
+    gchar	       *file;
 
     static const gchar *authors[] =
     {
@@ -410,6 +414,13 @@ about_cb(GtkWidget *w, gpointer data)
         NULL
     };
 
+    const gchar *documenters[] =
+    {
+	    NULL
+    };
+
+    const gchar *translator_credits = _("translator_credits");
+
     if (about != NULL)
     {
         gdk_window_show(about->window);
@@ -417,12 +428,28 @@ about_cb(GtkWidget *w, gpointer data)
         return;
     }
     
-    about = gnome_about_new (_("CD Player Applet"), VERSION,
+    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-cdplayer-icon.png", FALSE, NULL);
+    pixbuf = gdk_pixbuf_new_from_file (file, &error);
+    g_free (file);
+    
+    if (error) {
+    	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	g_error_free (error);
+    }
+    
+    about = gnome_about_new (_("CD Player"), VERSION,
                              _("(C) 1997 The Free Software Foundation\n" \
                                "(C) 2001 Chris Phelps (GNOME 2 Port)"),
                              _("The CD Player applet is a simple audio CD player for your panel"),
-                             authors,  NULL, NULL, NULL);
+                             authors,
+			     documenters,
+			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			     pixbuf);
+    if (pixbuf)
+    	gdk_pixbuf_unref (pixbuf);
 
+    gtk_window_set_wmclass (GTK_WINDOW (about), "cd player", "CD Player");
+    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-cdplayer-icon.png");	
     g_signal_connect (G_OBJECT(about), "destroy",
                       G_CALLBACK(gtk_widget_destroyed), &about);
     gtk_widget_show (about);
