@@ -55,10 +55,10 @@
 		char *tik_syms;
 		gboolean output;
 		gboolean scroll;
-		gboolean arrows;
 		gint timeout;
 		gchar *dcolor;
 		gchar *ucolor;
+		gchar *bgcolor;
 		gchar *font;
 		gchar *font2;
 		gboolean buttons;
@@ -79,13 +79,14 @@
 
 		int location;
 		int MOVE;
+		int delta;
 	
 		GArray *quotes;
 
 		int setCounter;
 
 		GdkGC *gc;
-		GdkColor gdkUcolor,gdkDcolor;
+		GdkColor gdkUcolor,gdkDcolor, gdkBGcolor;
 
 		/* end of COLOR vars */
 
@@ -109,10 +110,11 @@
 		gint timeout;
 		gint drawTimeID, updateTimeID;
 		/* For fonts */
-		GdkFont * my_font;
+		PangoFontDescription * my_font;
 		gchar * new_font;
-		GdkFont * extra_font;
-		GdkFont * small_font;
+		PangoFontDescription * extra_font;
+		PangoFontDescription * small_font;
+		PangoLayout *layout;
 		GtkTooltips * tooltips;
 		gint symbolfont;
 		gint whichlabel;
@@ -137,6 +139,8 @@
 			   guint a, gpointer data) ;
 	void dcolor_set_cb(GnomeColorPicker *cp, guint r, guint g, guint b,
 			   guint a, gpointer data) ;
+	void bgcolor_set_cb(GnomeColorPicker *cp, guint r, guint g, guint b,
+			   guint a, gpointer data) ;
 
 	/* end of color funcs */
 
@@ -159,46 +163,29 @@
 	/*-----------------------------------------------------------------*/
 	static void load_fonts(StockData *stockdata)
 	{
-		PangoFontDescription *font;
-		
 		if (stockdata->my_font)
-			gdk_font_unref (stockdata->my_font);
-		font = pango_font_description_from_string (stockdata->props.font);
-		stockdata->my_font = gdk_font_from_description (font);
-		pango_font_description_free (font);
-		
+			pango_font_description_free (stockdata->my_font);
+		stockdata->my_font = pango_font_description_from_string (stockdata->props.font);	
 
 		if (!stockdata->extra_font) {
-			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
+			stockdata->extra_font = pango_font_description_from_string ("Fixed 14");
 		}
 		
 		if (stockdata->small_font)
-				gdk_font_unref(stockdata->small_font);
-		font = pango_font_description_from_string (stockdata->props.font2);
-		stockdata->small_font = gdk_font_from_description (font);
-		pango_font_description_free (font);
+			pango_font_description_free (stockdata->small_font);
+		stockdata->small_font = pango_font_description_from_string (stockdata->props.font2);
 
-		if ( !stockdata->extra_font || (stockdata->props.arrows == FALSE ) ){
+		if ( !stockdata->extra_font  ){
 			
-			if (stockdata->extra_font)
-				gdk_font_unref(stockdata->extra_font);
-			font = pango_font_description_from_string ("fixed 12");
-			stockdata->extra_font = gdk_font_from_description (font);
-			pango_font_description_free (font);
+			stockdata->extra_font = pango_font_description_from_string ("fixed 12");
 			stockdata->symbolfont = 0;
 		}
-		else {
-			if (stockdata->extra_font)
-				gdk_font_unref(stockdata->extra_font);
-			stockdata->extra_font = gdk_font_load ("-*-symbol-medium-r-normal-*-*-140-*-*-p-*-adobe-fontspecific");
-			stockdata->symbolfont = 1;
-
-		}
+		
 		if (!stockdata->my_font) {
-			stockdata->my_font = gdk_font_load("fixed 12");
+			stockdata->my_font = pango_font_description_from_string ("fixed 12");
 		}
 		if (!stockdata->small_font) {
-			stockdata->small_font = gdk_font_load("fixed 12");
+			stockdata->small_font = pango_font_description_from_string ("fixed 12");
 		}
 
 	}
@@ -287,13 +274,15 @@ static gint updateOutput(gpointer data)
 		stockdata->props.scroll = panel_applet_gconf_get_bool (applet,
 									  "scroll",
 									  NULL);
-		stockdata->props.arrows = panel_applet_gconf_get_bool (applet,
-									  "arrows",
-									  NULL);
 		stockdata->props.timeout = panel_applet_gconf_get_int (applet,
 								       "timeout",
 								       NULL);
 		stockdata->props.timeout = MAX (stockdata->props.timeout, 1);
+		stockdata->props.bgcolor = panel_applet_gconf_get_string (applet,
+									 "bgcolor",
+									 NULL);
+		if (!stockdata->props.bgcolor)
+			stockdata->props.bgcolor = g_strdup ("#ffffff");
 		stockdata->props.dcolor = panel_applet_gconf_get_string (applet,
 									 "dcolor",
 									 NULL);
@@ -535,11 +524,14 @@ static gint updateOutput(gpointer data)
 		StockData *stockdata = data;
 		GtkWidget* drawing_area = stockdata->drawing_area;
 		GArray *quotes = stockdata->quotes;
-		GdkFont *my_font = stockdata->my_font;
-		GdkFont *small_font = stockdata->small_font;
-		GdkFont *extra_font = stockdata->extra_font;
+		PangoFontDescription *my_font = stockdata->my_font;
+		PangoFontDescription *small_font = stockdata->small_font;
+		PangoFontDescription *extra_font = stockdata->extra_font;
 		GdkGC *gc = stockdata->gc;
+		GdkGC *bg;
 		GdkRectangle update_rect;
+		PangoLayout *layout;
+		PangoRectangle logical_rect;
 		int	comp;
 
 		/* FOR COLOR */
@@ -548,29 +540,43 @@ static gint updateOutput(gpointer data)
 		int totalLen;
 		int i;
 
-
 		totalLoc = 0;
 		totalLen = 0;
-
-		/* clear the pixmap */
+	
+		bg = gdk_gc_new (stockdata->pixmap);
+		gdk_gc_set_foreground( bg, &stockdata->gdkBGcolor );
 		gdk_draw_rectangle (stockdata->pixmap,
-		drawing_area->style->black_gc,
-		TRUE,
-		0,0,
-		drawing_area->allocation.width,
-		drawing_area->allocation.height);
-
+				    bg, TRUE, 0,0,
+				    drawing_area->allocation.width,
+				    drawing_area->allocation.height);
+		g_object_unref (bg);
 
+		layout = stockdata->layout;
 		for(i=0;i<stockdata->setCounter;i++) {
-			totalLen += (gdk_string_width(my_font,
-				STOCK_QUOTE(quotes->data)[i].price) + 10);
+			pango_layout_set_font_description (layout, my_font);
+			pango_layout_set_text (layout,
+					       STOCK_QUOTE(quotes->data)[i].price,
+					       -1);			
+			pango_layout_get_pixel_extents (layout, NULL,
+							&logical_rect);
+			totalLen += logical_rect.width + 10;
 			if (stockdata->props.output == FALSE) {
 				if (*(STOCK_QUOTE(quotes->data)[i].change)) {
-					totalLen += (gdk_text_width(extra_font,
-								    STOCK_QUOTE(quotes->data)[i].change,1) + 10);
+					pango_layout_set_font_description (layout, extra_font);
+					if (g_utf8_validate (&STOCK_QUOTE(quotes->data)[i].change[0], 1, NULL)) {
+						pango_layout_set_text (layout, &STOCK_QUOTE(quotes->data)[i].change[0], 1);
+						pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
+						totalLen += logical_rect.width + 10;
+					}
 				}
-				totalLen += (gdk_string_width(small_font,
-						&STOCK_QUOTE(quotes->data)[i].change[1]) +10 );
+				pango_layout_set_font_description (layout,
+								   small_font);
+				pango_layout_set_text (layout,
+						       &STOCK_QUOTE(quotes->data)[i].change[1],
+						       -1);		
+				pango_layout_get_pixel_extents (layout, NULL,
+								&logical_rect);
+				totalLen += logical_rect.width +10;
 			}
 		}
 
@@ -584,19 +590,21 @@ static gint updateOutput(gpointer data)
 
 		  if (stockdata->props.scroll == TRUE) {
 			if (stockdata->location > comp) {
-				stockdata->location--;
+				stockdata->location -= stockdata->delta;	
 			}
 			else {
-				stockdata->location = drawing_area->allocation.width;
+				stockdata->location = drawing_area->allocation.width +
+						      stockdata->location - comp;
 			}
 
 		  }
 		  else {
                        if (stockdata->location < drawing_area->allocation.width) {
-                                stockdata->location ++;
+                                stockdata->location += stockdata->delta;    
                         }
                         else {
-                                stockdata->location = comp;
+                                stockdata->location = comp + stockdata->location -
+                                		      drawing_area->allocation.width;
                         }
 		  }
 
@@ -614,31 +622,46 @@ static gint updateOutput(gpointer data)
 				gdk_gc_set_foreground( gc, &stockdata->gdkDcolor );
 			}
 			else {
-				gdk_gc_copy( gc, drawing_area->style->white_gc );
+				gdk_gc_copy( gc, drawing_area->style->black_gc );
 			}
 
 			tmpSym = STOCK_QUOTE(quotes->data)[i].price;
-			gdk_draw_string (stockdata->pixmap,my_font, gc,
-					 stockdata->location + totalLoc ,14,
-					 STOCK_QUOTE(quotes->data)[i].price);
-
-			totalLoc += (gdk_string_width(my_font,tmpSym) + 10); 
+			pango_layout_set_font_description (layout, my_font);
+			pango_layout_set_text (layout,
+					       STOCK_QUOTE(quotes->data)[i].price,
+					       -1);	
+			gdk_draw_layout (stockdata->pixmap, gc,
+					 stockdata->location + totalLoc , 3,
+					 layout);
+			pango_layout_get_pixel_extents (layout, NULL,
+							&logical_rect);
+			totalLoc += logical_rect.width + 10;
 
 
 			if (stockdata->props.output == FALSE) {
 				tmpSym = STOCK_QUOTE(quotes->data)[i].change;
 				if (*(STOCK_QUOTE(quotes->data)[i].change)) {
-					gdk_draw_text (stockdata->pixmap,extra_font,
-					     gc, stockdata->location + totalLoc,
-					     14,STOCK_QUOTE(quotes->data)[i].change,1);
-					totalLoc += (gdk_text_width(extra_font,
-							STOCK_QUOTE(quotes->data)[i].change,1) + 5);
+					pango_layout_set_font_description (layout, extra_font);
+					if (g_utf8_validate (&STOCK_QUOTE(quotes->data)[i].change[0], 1, NULL)) {
+						pango_layout_set_text (layout, &STOCK_QUOTE(quotes->data)[i].change[0], 1);
+						gdk_draw_layout (stockdata->pixmap,
+					     		gc, stockdata->location + totalLoc,
+					     		3, layout);
+						pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
+						totalLoc += logical_rect.width + 5;
+					}
 				}
-				gdk_draw_string (stockdata->pixmap,small_font,
+				pango_layout_set_font_description (layout,
+								   small_font);	
+				pango_layout_set_text (layout,
+						       &STOCK_QUOTE(quotes->data)[i].change[1],
+						       -1);		
+				gdk_draw_layout (stockdata->pixmap,
 				     gc, stockdata->location + totalLoc,
-				     14, &STOCK_QUOTE(quotes->data)[i].change[1]);
-				totalLoc += (gdk_string_width(small_font,
-						tmpSym) + 10); 
+				     3, layout);
+				pango_layout_get_pixel_extents (layout, NULL,
+								&logical_rect);
+				totalLoc += logical_rect.width + 10;
 			}
 			
 		}
@@ -647,7 +670,11 @@ static gint updateOutput(gpointer data)
 		update_rect.width = drawing_area->allocation.width;
 		update_rect.height = drawing_area->allocation.height;
 
-		gtk_widget_draw(drawing_area,&update_rect);
+		gtk_widget_queue_draw_area (drawing_area,
+					    update_rect.x,
+					    update_rect.y,
+					    update_rect.width,
+					    update_rect.height);
 		return 1;
 	}
 
@@ -658,14 +685,37 @@ static gint updateOutput(gpointer data)
 	static void about_cb (BonoboUIComponent *uic, gpointer data, 
 			      const gchar *verbname) {
 		GtkWidget *about;
+		GdkPixbuf *pixbuf;
+		GError    *error = NULL;
+		gchar     *file;
 		static const gchar *authors[] = {
 			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
 			"Rached Blili <striker@dread.net>",
 			NULL
 		};
+		
+		const gchar *documenters[] = {
+			NULL
+		};
 
-		about = gnome_about_new (_("The GNOME Stock Ticker"), VERSION,
+		const gchar *translator_credits = _("translator_credits");
+		
+		
+		file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+			"gnome-money.png", FALSE, NULL);
+		
+		pixbuf = gdk_pixbuf_new_from_file (file, &error);
+		
+		g_free (file);
+		
+		if (error) {
+			g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+			
+			g_error_free (error);
+		}
+		
+		about = gnome_about_new (_("Stock Ticker"), VERSION,
 		"(C) 2000 Jayson Lorenzen, Jim Garrison, Rached Blili",
 		_("This program connects to "
 		"a popular site and downloads current stock quotes.  "
@@ -674,9 +724,16 @@ static gint updateOutput(gpointer data)
 		"Do not use the GNOME Stock Ticker for making investment decisions; it is for "
 		"informational purposes only."),
 		authors,
-		NULL,
-		NULL,
-		NULL);
+		documenters,
+		strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		pixbuf);
+		
+		if (pixbuf)
+			gdk_pixbuf_unref (pixbuf);
+		
+		gnome_window_icon_set_from_file (GTK_WINDOW (about),
+			GNOME_ICONDIR"/gnome-money.png");
+		
 		gtk_widget_show (about);
 
 		return;
@@ -700,9 +757,13 @@ static gint updateOutput(gpointer data)
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = TRUE;
-		for (i=0;i<151;i++) {
+		stockdata->delta = 150;
+		stockdata->MOVE = 0;
+		/*for (i=0;i<151;i++) {
 			Repaint(stockdata);
-		}
+		}*/
+		Repaint(stockdata);
+		stockdata->delta = 1;
 		stockdata->props.scroll = current;
 	}
 
@@ -714,9 +775,14 @@ static gint updateOutput(gpointer data)
 
 		current = stockdata->props.scroll;
 		stockdata->props.scroll = FALSE;
+		stockdata->delta = 150;
+		stockdata->MOVE = 0;
+		/*
 		for (i=0;i<151;i++) {
 			Repaint(stockdata);
-		}
+		}*/
+		Repaint(stockdata);
+		stockdata->delta = 1;
 		stockdata->props.scroll = current;
 	}
 
@@ -778,29 +844,7 @@ static gint updateOutput(gpointer data)
 					     stockdata->props.scroll, NULL);
 					     
 	}
-	
-	static void
-	arrows_toggled (GtkToggleButton *button, gpointer data)
-	{
-		StockData *stockdata = data;
-		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
 		
-		if (stockdata->props.arrows == gtk_toggle_button_get_active (button))
-			return;
-			
-		stockdata->props.arrows = gtk_toggle_button_get_active (button);
-		panel_applet_gconf_set_bool (applet,"arrows",
-					     stockdata->props.arrows, NULL);
-		load_fonts (stockdata);
-		if (!configured(stockdata)) {
-			reSetOutputArray(stockdata);
-			fprintf(stderr, "No data!\n");
-			setOutputArray(stockdata,
-				       _("No data available or properties not set"));
-		}
-					     
-	}
-	
 	static void
 	scroll_toggled (GtkToggleButton *button, gpointer data)
 	{
@@ -1257,7 +1301,7 @@ static gint updateOutput(gpointer data)
     		          G_CALLBACK (proxy_port_changed), stockdata);
     		set_relation (stockdata->proxy_port_entry, GTK_LABEL (label));
     		
-    		stockdata->proxy_auth_button = gtk_check_button_new_with_mnemonic (_("Pro_xy requires a uername and password"));
+    		stockdata->proxy_auth_button = gtk_check_button_new_with_mnemonic (_("Pro_xy requires a username and password"));
     		gtk_box_pack_start (GTK_BOX (vbox), stockdata->proxy_auth_button, 
     				    FALSE, FALSE, 0);
     		gtk_toggle_button_set_active 
@@ -1314,6 +1358,10 @@ static gint updateOutput(gpointer data)
     		gtk_widget_set_sensitive (stockdata->proxy_port_entry, use_proxy);
     		gtk_widget_set_sensitive (stockdata->proxy_passwd_entry, use_proxy);
     		gtk_widget_set_sensitive (stockdata->proxy_user_entry, use_proxy);
+    		
+    		g_free (proxy_url);
+    		g_free (proxy_psswd);
+    		g_free (proxy_user);
     			
 		gtk_widget_show_all (vbox);
 		return vbox;
@@ -1344,7 +1392,8 @@ static gint updateOutput(gpointer data)
 		GtkWidget *timeout_label,*timeout_c;
 		GtkObject *timeout_a;
 		GtkWidget *upColor, *downColor, *upLabel, *downLabel;
-		GtkWidget *check, *check2, *check3, *check4, *fontButton;
+		GtkWidget *bgColor, *bgLabel;
+		GtkWidget *check, *check2, *check4, *fontButton;
 		GtkWidget *font_picker;
 
 		int ur,ug,ub, dr,dg,db; 
@@ -1409,9 +1458,6 @@ static gint updateOutput(gpointer data)
 		check2 = gtk_check_button_new_with_mnemonic(_("Scroll _left to right"));
 		g_signal_connect (G_OBJECT (check2), "toggled",
 				  G_CALLBACK (rtl_toggled), stockdata);
-		check3 = gtk_check_button_new_with_mnemonic(_("Display a_rrows instead of -/+"));
-		g_signal_connect (G_OBJECT (check3), "toggled",
-				  G_CALLBACK (arrows_toggled), stockdata);
 		check4 = gtk_check_button_new_with_mnemonic(_("_Enable scroll buttons"));
 		g_signal_connect (G_OBJECT (check4), "toggled",
 				  G_CALLBACK (scroll_toggled), stockdata);
@@ -1419,7 +1465,6 @@ static gint updateOutput(gpointer data)
 
 		gtk_box_pack_start(GTK_BOX(vbox2), check, FALSE, FALSE, GNOME_PAD);
 		gtk_box_pack_start(GTK_BOX(vbox2), check2, FALSE, FALSE, GNOME_PAD);
-		gtk_box_pack_start(GTK_BOX(vbox), check3, FALSE, FALSE, GNOME_PAD);
 		gtk_box_pack_start(GTK_BOX(vbox), check4, FALSE, FALSE, GNOME_PAD);
 
 
@@ -1433,10 +1478,7 @@ static gint updateOutput(gpointer data)
 		if (stockdata->props.buttons == TRUE)
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check4),
 							TRUE);
-		if (stockdata->props.arrows == TRUE)
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check3),
-							TRUE);
-
+		
 		/* COLOR */
 		upLabel = gtk_label_new_with_mnemonic(_("+ C_olor"));
 		upColor = gnome_color_picker_new();
@@ -1474,6 +1516,24 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_start_defaults( GTK_BOX(hbox3), downLabel );
 		gtk_box_pack_start_defaults( GTK_BOX(hbox3), downColor );
 		gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
+		
+		bgLabel = gtk_label_new_with_mnemonic(_("Back_ground Color"));
+		bgColor = gnome_color_picker_new();
+		
+		set_relation(bgColor, GTK_LABEL(bgLabel));
+
+		sscanf( stockdata->props.bgcolor, "#%02x%02x%02x", &dr,&dg,&db );
+
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER (bgColor), 
+					  dr, dg, db, 255);
+
+		gtk_signal_connect(GTK_OBJECT(bgColor), "color_set",
+				GTK_SIGNAL_FUNC(bgcolor_set_cb), stockdata);
+
+		hbox3 = gtk_hbox_new(FALSE, 5);
+		gtk_box_pack_start_defaults( GTK_BOX(hbox3), bgLabel );
+		gtk_box_pack_start_defaults( GTK_BOX(hbox3), bgColor );
+		gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
 		gtk_box_pack_start_defaults(GTK_BOX(panela),vbox3);
 
                 /* For FONTS */
@@ -1555,6 +1615,7 @@ static gint updateOutput(gpointer data)
 		access_stock = stockdata = g_new0 (StockData, 1);
 		stockdata->applet = GTK_WIDGET (applet);
 		stockdata->timeout = 0;
+		stockdata->delta = 1;
 		stockdata->vfshandle = NULL;
 		stockdata->configFileName = g_strconcat (g_getenv ("HOME"), 
 						         "/.gtik.conf", NULL);
@@ -1582,6 +1643,9 @@ static gint updateOutput(gpointer data)
 		gtk_drawing_area_size(GTK_DRAWING_AREA (stockdata->drawing_area),200,20);
 
 		gtk_widget_show(stockdata->drawing_area);
+
+		stockdata->layout = gtk_widget_create_pango_layout (stockdata->drawing_area, "");
+
 		gtk_container_add(GTK_CONTAINER(frame),stockdata->drawing_area);
 		
 		gtk_widget_show(frame);
@@ -1622,7 +1686,7 @@ static gint updateOutput(gpointer data)
 				                   stockdata);
 
 		/* KEEPING TIMER ID FOR CLEANUP IN DESTROY */
-		stockdata->drawTimeID = gtk_timeout_add(4,Repaint,stockdata);
+		stockdata->drawTimeID = gtk_timeout_add(40,Repaint,stockdata);
 		stockdata->updateTimeID = gtk_timeout_add(stockdata->props.timeout * 60000,
 				                          updateOutput,stockdata);
 
@@ -1669,6 +1733,7 @@ static gint updateOutput(gpointer data)
 	static void destroy_applet(GtkWidget *widget, gpointer data) {
 		StockData *stockdata = data;
 
+		g_object_unref (G_OBJECT (stockdata->layout));
 		g_object_unref (G_OBJECT (stockdata->tooltips));
 
 		if (stockdata->drawTimeID > 0) { 
@@ -1680,11 +1745,11 @@ static gint updateOutput(gpointer data)
 		if (stockdata->configFileName)
 			g_free (stockdata->configFileName);
 		if (stockdata->my_font)
-			gdk_font_unref (stockdata->my_font);
+			pango_font_description_free (stockdata->my_font);
 		if (stockdata->extra_font)
-			gdk_font_unref (stockdata->extra_font);
+			pango_font_description_free (stockdata->extra_font);
 		if (stockdata->small_font)
-			gdk_font_unref (stockdata->small_font);
+			pango_font_description_free (stockdata->small_font);
 	}
 
 
@@ -1740,14 +1805,18 @@ static gint updateOutput(gpointer data)
 			return data;
 
 		if (var3[0] == '+') { 
+#if 0
 			if (stockdata->symbolfont)
 				var3[0] = 221;
+#endif
 			var4[0] = '(';
 			quote->color = GREEN;
 		}
 		else if (var3[0] == '-') {
+#if 0
 			if (stockdata->symbolfont)
 				var3[0] = 223;	
+#endif
 			var4[0] = '(';
 			quote->color = RED;
 		}
@@ -1796,6 +1865,9 @@ static gint updateOutput(gpointer data)
 
 		gdk_color_parse(stockdata->props.dcolor, &stockdata->gdkDcolor);
 		gdk_color_alloc(colormap, &stockdata->gdkDcolor);
+		
+		gdk_color_parse(stockdata->props.bgcolor, &stockdata->gdkBGcolor);
+		gdk_color_alloc(colormap, &stockdata->gdkBGcolor);
 
 	}
 
@@ -1840,6 +1912,22 @@ static gint updateOutput(gpointer data)
 		
 		setup_colors(stockdata);
 	}
+	
+	void bgcolor_set_cb(GnomeColorPicker *cp, guint r, guint g, guint b,
+			   guint a, gpointer data) {
+		StockData *stockdata = data;
+		PanelApplet *applet = PANEL_APPLET (stockdata->applet);
+		guint8 red, gr, bl;
+		
+		if (stockdata->props.bgcolor)
+			g_free (stockdata->props.bgcolor);
+		gnome_color_picker_get_i8 (GNOME_COLOR_PICKER(cp), &red, &gr, &bl, NULL);
+		stockdata->props.bgcolor = g_strdup_printf("#%06X", (red << 16) + (gr << 8) + bl);
+		panel_applet_gconf_set_string (applet, "bgcolor", 
+					       stockdata->props.bgcolor, NULL);
+		
+		setup_colors(stockdata);
+	}
 
 
 
