@@ -46,7 +46,7 @@
 static const gchar *preferences_menu_xml =
 	"    <placeholder name=\"ChildItem\">\n"
 	"%s"
-	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Preferences\"\n"
+	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove Preferences Menu\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-close\"/>\n"
 	"        <separator/>"
 	"    </placeholder>";
@@ -177,8 +177,8 @@ panel_menu_preferences_save_config (PanelMenuEntry *entry)
 {
 	PanelMenuPreferences *preferences;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_PREFERENCES);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_PREFERENCES, NULL);
 
 	preferences = (PanelMenuPreferences *)entry->data;
 
